# neoscore.core

### The most fundamental building blocks of neoscore

This package contains most of the classes central to `neoscore`, including basic graphic primitives (`Path`, `Text`, etc), document layout primitives, SMuFL music font binding logic, and higher-level notation primitives such as `Staff` and `Chordrest`.
